﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Core.Layers;

namespace CompositeChart
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraChart1.ChartType = ChartType.Composite;
            
            ChartArea area = new ChartArea();
            this.ultraChart1.CompositeChart.ChartAreas.Add(area);

            AxisItem axisY1 = new AxisItem();
            axisY1.Extent = 80;
            axisY1.DataType = AxisDataType.String;
            axisY1.Labels.ItemFormat = AxisItemLabelFormat.ItemLabel;
            //axisY1.Labels.ItemFormatString = "<DATA_VALUE:##.##>";
            axisY1.OrientationType = AxisNumber.Y_Axis;
            axisY1.SetLabelAxisType = SetLabelAxisType.GroupBySeries;
            axisY1.LineColor = Color.Blue;
            area.Axes.Add(axisY1);

            AxisItem axisY2 = new AxisItem();
            axisY2.Extent = 120;
            axisY2.RangeType = AxisRangeType.Custom;
            axisY2.RangeMin = 0;
            axisY2.RangeMax = 400;
            axisY2.DataType = AxisDataType.Numeric;
            axisY2.Labels.ItemFormatString = "<DATA_VALUE:##.####>";
            axisY2.OrientationType = AxisNumber.Y_Axis;
            axisY2.LineColor = Color.Blue;
            axisY2.SetLabelAxisType = SetLabelAxisType.DateData;
            area.Axes.Add(axisY2);

            AxisItem axisX1 = new AxisItem();
            axisX1.DataType = AxisDataType.Numeric;
            axisX1.Labels.ItemFormat = AxisItemLabelFormat.DataValue;
            axisX1.Labels.ItemFormatString = "<DATA_VALUE> lbs";
            axisX1.OrientationType = AxisNumber.X_Axis;
            axisX1.SetLabelAxisType = SetLabelAxisType.ContinuousData;
            area.Axes.Add(axisX1);
            axisX1.ScrollScale.Visible = true;

            AxisItem axisX2 = new AxisItem();
            axisX2.DataType = AxisDataType.Time;
            axisX2.Extent = 50;
            axisX2.Labels.ItemFormatString = "<ITEM_LABEL>";
            axisX2.OrientationType = AxisNumber.X_Axis;
            axisX2.Labels.Orientation = TextOrientation.Custom;
            axisX2.Labels.HorizontalAlign = StringAlignment.Center;
            axisX2.Labels.OrientationAngle = 45;
            axisX2.SetLabelAxisType = SetLabelAxisType.DateData;
            area.Axes.Add(axisX2);
            axisX2.ScrollScale.Visible = true;

            //Create a ChartLayer for each series
            ChartLayerAppearance myColumnLayer = new ChartLayerAppearance();
            myColumnLayer.ChartType = ChartType.BarChart;
            myColumnLayer.ChartArea = area;

            ChartLayerAppearance myColumnLayer2 = new ChartLayerAppearance();
            myColumnLayer2.ChartType = ChartType.AreaChart;
            myColumnLayer2.ChartArea = area;

            DataTable dt = new DataTable();
            dt.Columns.Add("LabCol");
            dt.Columns.Add("BarValue");
            dt.Columns.Add("TimeValue");
            dt.Columns.Add("AreaValue");

            dt.Rows.Add("Item 1", 5, DateTime.Today, 100);
            dt.Rows.Add("Item 2", 10, DateTime.Today.AddDays(1), 200);
            dt.Rows.Add("Item 3", 25, DateTime.Today.AddDays(2), 150);
            dt.Rows.Add("Item 4", 15, DateTime.Today.AddDays(3), 220);
            dt.Rows.Add("Item 5", 20, DateTime.Today.AddDays(4), 250);
            dt.Rows.Add("Item 6", 30, DateTime.Today.AddDays(5), 180);



            NumericSeries series1 = new NumericSeries();
            series1.DataBind(dt, "BarValue", "LabCol");
            series1.Label = "BarChart" + Environment.NewLine + "Items";
            ultraChart1.Tooltips.FormatString = "<SERIES_LABEL:MMM yyyy>" + Environment.NewLine + "<ITEM_LABEL>: <DATA_VALUE:00.##>";
            myColumnLayer.Series.Add(series1);
            ultraChart1.CompositeChart.Series.Add(series1);
            

            //Other possible approach for DataBinding
            NumericTimeSeries series2 = new NumericTimeSeries();
            series2.DataBind(dt, "TimeValue", "AreaValue");
            series2.PEs.Add(new PaintElement(Color.Yellow));
            myColumnLayer2.Series.Add(series2);
            ultraChart1.CompositeChart.Series.Add(series2);

            
            // Set axis for each Chart Layer
            myColumnLayer.AxisX = axisX1;
            myColumnLayer.AxisY = axisY1;
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer);

            myColumnLayer2.AxisX = axisX2;
            myColumnLayer2.AxisY = axisY2;
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer2);


        }
    }
}